//---------------------------------------------------------------------------

#ifndef ButtonConfH
#define ButtonConfH
//---------------------------------------------------------------------------

#include "ButtonType.h"
#include <string>

class ButtonConf
{
public:
	Button::Type type;
	std::string caption;
	std::string number;
	bool noIcon;
	int height;
	int marginTop;
	int marginBottom;

	std::string imgIdle;
	std::string imgTerminated;
	std::string imgEarly;
	std::string imgConfirmed;

	std::string arg1;

	/** Overrides default number when BLF button is pressed
		(calls to other number than subscribed)
	*/
	struct BlfOverride
	{
		bool active;
		std::string number;
		BlfOverride(void):
			active(false)
		{}
	} blfOverrideIdle, blfOverrideTerminated, blfOverrideEarly, blfOverrideConfirmed;

	enum BlfActionDuringCall
	{
		BLF_IN_CALL_NONE = 0,
		BLF_IN_CALL_DTMF,
		BLF_IN_CALL_TRANSFER,
		
		BLF_IN_CALL_LIMITER
	} blfActionDuringCall;

	/** Prefix to be added when BLF is pressed during call
		and BLF is configured to send DTMF
	*/
	std::string blfDtmfPrefixDuringCall;

	ButtonConf():
		type(Button::DISABLED),
		noIcon(false),
		height(32),
		marginTop(0),
		marginBottom(0),
		imgIdle("idle.bmp"),
		imgTerminated("terminated.bmp"),
		imgEarly("early.bmp"),
		imgConfirmed("confirmed.bmp"),
		blfActionDuringCall(BLF_IN_CALL_TRANSFER)
	{
	}

	bool operator==(const ButtonConf& right) const {
		return (
			type == right.type &&
			number == right.number &&
			caption == right.caption &&
			noIcon == right.noIcon &&
			height == right.height &&
			marginTop == right.marginTop &&
			marginBottom == right.marginBottom &&
			imgIdle == right.imgIdle &&
			imgTerminated == right.imgTerminated &&
			imgEarly == right.imgEarly &&
			imgConfirmed == right.imgConfirmed
			);
	}
	
	bool operator!=(const ButtonConf& right) const {
		return !(*this == right);
	}                               
};

#endif
